%define name		PowerDNS
%define version		2.9.6
%define release		3mdk

Summary:		PowerDNS is a Versatile Database Driven Nameserver
Name:			%{name}
Version:		%{version}
Release:		%{release}
License:		GPL
Group:			System/Servers
URL:			http://www.powerdns.com/
Source0:		pdns-%{version}.tar.bz2
Patch0:			pdns-2.9.2-init.patch.bz2

# wget -rm http://rtfm.powerdns.com
Source1:		rtfm.powerdns.com.tar.bz2

PreReq:			rpm-helper
BuildRequires:		bison flex libmysql12-devel libopenssl0.9.7-devel libstdc++5-devel
BuildRequires:		libtdb1-devel zlib1-devel postgresql-devel
BuildRequires:		libpq++4-devel libpq++4-static-devel libpq3-devel
BuildRequires:		libldap2-devel libsasl7-devel libgdbm2-devel

BuildRoot:		%{_tmppath}/%{name}-%{version}-buildroot
Provides:		nameserver pdns powerdns
Obsoletes:		nameserver pdns powerdns
Conflicts:		tmdns

%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

This RPM is statically compiled and should work on all Linux distributions.
It comes with support for MySQL, PostgreSQL, Bind zonefiles and the 'pipe
backend' availible as external packages.

%package		backend-pipe
Summary:		Pipe/coprocess backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		backend-pipe
This package contains the pipe backend for the PowerDNS nameserver. This
allows PowerDNS to retrieve domain info from a process that accepts
questions on stdin and returns answers on stdout. 

%package		backend-mysql
Summary:		MySQL backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		libmysql12 

%description		backend-mysql
This package contains a MySQL backend for the PowerDNS nameserver.

%package		backend-pgsql
Summary:		Generic PostgreSQL backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		libopenssl0.9.7 libpq++4 libpq3 libgcc1 libstdc++5

%description		backend-pgsql
This package contains a generic PostgreSQL backend 
for the PowerDNS nameserver. It has configurable SQL statements.

%package		backend-xdb
Summary:		XDB/tdb/gdb backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		libtdb1

%description		backend-xdb
This package contains a table backend for PowerDNS. Currently includes TDB,
the Trivial Database or Tridgell Database.

%package		backend-ldap
Summary:		LDAP backend for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		libldap2 libsasl7

%description		backend-ldap
This package contains a LDAP backend for the PowerDNS nameserver.

%package		devel
Summary:		Development headers and libraries for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		%{name}-backend-pipe = %{version}
Requires:		%{name}-backend-mysql = %{version}
Requires:		%{name}-backend-pgsql = %{version}
Requires:		%{name}-backend-xdb = %{version}
Requires:		%{name}-backend-ldap = %{version}

%description		devel
Development headers and libraries for %{name}

%package		static-devel
Summary:		Static libraries for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}
Requires:		%{name}-devel = %{version}
Requires:		%{name}-backend-pipe = %{version}
Requires:		%{name}-backend-mysql = %{version}
Requires:		%{name}-backend-pgsql = %{version}
Requires:		%{name}-backend-xdb = %{version}
Requires:		%{name}-backend-ldap = %{version}

%description		static-devel
Static libraries for %{name}

%prep

%setup -q -n pdns-%{version} -a1
%patch0 -p0

%build
%serverbuild
./configure \
    --prefix=%{_prefix} \
    --exec-prefix=%{_exec_prefix} \
    --bindir=%{_bindir} \
    --sbindir=%{_sbindir} \
    --sysconfdir=%{_sysconfdir}/powerdns \
    --datadir=%{_datadir} \
    --includedir=%{_includedir} \
    --libdir=%{_libdir}/powerdns \
    --libexecdir=%{_libexecdir} \
    --localstatedir=%{_localstatedir} \
    --sharedstatedir=%{_sharedstatedir} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --with-socketdir=/var/run \
    --with-dynmodules="gmysql gpgsql pipe xdb ldap" \
    --with-modules="" \
    --with-mysql=%{_prefix} \
    --with-pgsql=%{_prefix}

%make

# this might work someday..., meanwhile use S1
#pushd pdns/docs
#    make
#popd

%install
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}

# don't fiddle with the initscript!
export DONT_GPRINTIFY=1

make DESTDIR="%{buildroot}" install

# fix the config
mv %{buildroot}%{_sysconfdir}/powerdns/pdns.conf-dist %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

cat >> %{buildroot}%{_sysconfdir}/powerdns/pdns.conf << EOF
module-dir=%{_libdir}/powerdns
socket-dir=/var/run/
setuid=powerdns
setgid=powerdns
launch=bind
EOF

chmod 600 %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

# install sysv script
install -d %{buildroot}%{_initrddir}
install -m755 pdns/pdns %{buildroot}%{_initrddir}/powerdns

%pre
%_pre_useradd powerdns /var/lib/powerdns /bin/false

%post
%_post_service powerdns

%preun
%_preun_service powerdns

%postun
%_postun_userdel powerdns

%clean
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc ChangeLog HACKING INSTALL README TODO WARNING rtfm.powerdns.com
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/pdns.conf
%config(noreplace) %attr(0755,root,root) %{_initrddir}/powerdns
%dir %{_sysconfdir}/powerdns
%dir %{_libdir}/powerdns
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man8/*

%files backend-pipe
%defattr(-,root,root)
%{_libdir}/powerdns/libpipebackend.so.*

%files backend-mysql
%defattr(-,root,root)
%{_libdir}/powerdns/libgmysqlbackend.so.*

%files backend-pgsql
%defattr(-,root,root)
%{_libdir}/powerdns/libgpgsqlbackend.so.*

%files backend-xdb
%defattr(-,root,root)
%{_libdir}/powerdns/libxdbbackend.so.*

%files backend-ldap
%defattr(-,root,root)
%{_libdir}/powerdns/libldapbackend.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/powerdns/*.so
%{_libdir}/powerdns/*.la

%files static-devel
%defattr(-,root,root)
%{_libdir}/powerdns/*.a

%changelog
* Tue Mar 11 2003 Marcel Pol <mpol@gmx.net> 2.9.6-3mdk
- conflicts: tmdns

* Mon Mar 10 2003 Marcel Pol <mpol@gmx.net> 2.9.6-2mdk
- buildreq: libgdbm2-devel

* Mon Feb 17 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.9.6-1mdk
- 2.9.6
- added the backend-ldap sub package
- misc spec file fixes
- built against latest requires and buildrequires

* Sat Jan 18 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.9.4-1mdk
- 2.9.4
- added missing stuff in %{_bindir}/
- broke out the modules into separate sub packages, used the
  debian descriptions
- added development sub packages
- misc spec file fixes

* Tue Dec 17 2002 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.9.2-1mdk
- initial cooker contrib (i cross my fingers that it works on first try...)


